@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Moose;
 use namespace::autoclean;
@@ -24,6 +24,7 @@ has 'place' => ( is => 'rw', isa => 'Str', default => sub { 'top' } );
 sub after_build {
     my ($self) = @_;
 
+    my $distname = $self->zilla->name;
     my $distmeta = $self->zilla->distmeta;
     my $repository = $distmeta->{resources}->{repository}->{url};
     return unless $repository;
@@ -48,7 +49,7 @@ sub after_build {
         } elsif ($badge eq 'gitter') {
             push @badges, "[![Gitter chat](https://badges.gitter.im/$user_name/$repository_name.png)](https://gitter.im/$user_name/$repository_name)";
         } elsif ($badge eq 'cpants') {
-            push @badges, "![](http://cpants.cpanauthors.org/dist/$repository_name.png)";
+            push @badges, "![](http://cpants.cpanauthors.org/dist/$distname.png)";
         }
     }
 
